import { getUserMoneyApi } from "@/api/user";
import { Link } from "@/i18n";
import { useGlobalStore } from "@/stores";
import clsx from "clsx";
import { useTranslations } from "next-intl";
import { FC, ReactNode, useEffect, useRef, useState } from "react";
import HeaderTitle from "./HerderTitle";
import styles from "./style.module.scss";
/**
 * @description HeaderProps
 * @param {boolean} headerPlaceholder 是否展示展位元素
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderProps {
    headerPlaceholder?: boolean;
    headerRender?: () => ReactNode;
    menuHandler?: () => void;
}

const cs = clsx(["iconfont icon-gengduo", styles.menu]);
const DefaultHeader: FC<HeaderProps> = (props) => {
    const { menuHandler } = props;
    const t = useTranslations("Header");
    const { token, userInfo } = useGlobalStore();
    const [money, setMoney] = useState(0);

    const timer = useRef<NodeJS.Timeout | null>(null);

    useEffect(() => {
        if (token) {
            timer.current = setInterval(() => {
                getUserMoneyApi().then((res) => {
                    setMoney(res.data.Score);
                });
            }, 5000);
        }
        return () => {
            clearTimeout(timer.current!);
            timer.current = null;
        };
    }, [token]);

    return (
        <div className={styles.headerMain}>
            <div className={styles.headerLeft} onClick={menuHandler}>
                {/*<div className={cs}></div>*/}
            </div>
            <HeaderTitle />
            <div className={styles.headerRight}>
                <div className={styles.right}>
                    {userInfo ? (
                        <>
                            <Link href={"/profile"}>
                                <div className={"flex items-center text-[0.12rem]"}>
                                    <i className={"iconfont icon-yonghu mr-[0.03rem]"}></i>
                                    <span>{money}</span>
                                </div>
                            </Link>

                            <Link href={"/deposit"} className={styles.rightActive}>
                                {t("deposit")}
                            </Link>
                        </>
                    ) : (
                        <>
                            <Link href={"/login?redirect=/"}>{t("login")}</Link>
                            <Link href={"/login?redirect=/"} className={styles.rightActive}>
                                {t("register")}
                            </Link>
                        </>
                    )}
                </div>
            </div>
        </div>
    );
};

const Header: FC<HeaderProps> = (props) => {
    const { headerPlaceholder = true, headerRender, ...other } = props;
    const cs = clsx({
        [styles.placeholder]: headerPlaceholder,
    });
    return (
        <div className={cs}>
            <div className={styles.headerWrap}>
                {headerRender ? headerRender() : <DefaultHeader {...other} />}
            </div>
        </div>
    );
};
export default Header;
